# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).



## [v0.0.6] - 2021-07-14

**Updates**

- Add missing requirements - 75abb48af855340e984e2dea525b9e3a2c26862e

## [v0.0.5] - 2021-07-11

**Changed**

- Removed support for `--package_name` flag. Instead use `package` in `config.toml/.yaml`

## [v0.0.4] - 2021-07-10

**Changed**

- The method signature of base class changed, and method renamed - b4c4c6baec6dd286114659226a8c1e8cabbc9a67

## [v0.0.3] - 2021-07-10

This release adds the ability to update cloud providers. For more information see [Providers](http://127.0.0.1:5500/docs/providers/index.html).

**New**

- Added cloud providers
    - [Cloudflare](https://akshaybabloo.github.io/uHugo/providers/cloudflare.html)

**Updated**

- rich library updated - #3 
- packaging library updated - #4 

## [v0.0.2] - 2021-07-08

Initial release


[Unreleased]: https://github.com/akshaybabloo/uHugo/compare/v0.0.6...HEAD
[v0.0.6]: https://github.com/akshaybabloo/uHugo/compare/v0.0.5...v0.0.6
[v0.0.5]: https://github.com/akshaybabloo/uHugo/compare/v0.0.4...v0.0.5
[v0.0.4]: https://github.com/akshaybabloo/uHugo/compare/v0.0.3...v0.0.4
[v0.0.3]: https://github.com/akshaybabloo/uHugo/compare/v0.0.2...v0.0.3